@@ -212,6 +212,37 @@ def get_display_name():
 	return ""
 
 
+def get_display_number(display_no):
+	""" Translate from Argyll display index to wx display index """
+	from wxaddons import wx
+	try:
+		display = getcfg("displays").split(os.pathsep)[display_no]
+	except IndexError:
+		pass
+	else:
+		for i in xrange(wx.Display.GetCount()):
+			geometry = "%i, %i, %ix%i" % tuple(wx.Display(i).Geometry)
+			if display.find("@ " + geometry) > -1:
+				if debug:
+					from log import safe_print
+					safe_print("[D] Found display %s at index %i" % 
+							   (geometry, i))
+				display_no = i
+				break
+	return display_no
+
+
+def get_display_rects():
+	""" Return the Argyll enumerated display coordinates and sizes """
+	from wxaddons import wx
+	display_rects = []
+	for i, display in enumerate(getcfg("displays").split(os.pathsep)):
+		match = re.search("@ (-?\d+), (-?\d+), (\d+)x(\d+)", display)
+		if match:
+			display_rects.append(wx.Rect(*[int(item) for item in match.groups()]))
+	return display_rects
+
+
 def get_icon_bundle(sizes, name):
 	""" Return a wx.IconBundle with given icon sizes """
 	from wxaddons import wx
@@ -363,7 +394,7 @@ valid_ranges = {
 valid_values = {
 	"3dlut.bitdepth.input": [0, 1, 2, 3, 4],
 	"3dlut.bitdepth.output": [0, 1, 2, 3, 4],
-	"3dlut.format": [0, 1],
+	"3dlut.format": [0, 1, 2],
 	"3dlut.rendering_intent": [0, 1, 2, 3],
 	"3dlut.size": [0, 1, 2],
 	"calibration.quality": ["v", "l", "m", "h", "u"],
@@ -394,9 +425,11 @@ defaults = {
 	"3dlut.bitdepth.output": 2,
 	"3dlut.format": 0,
 	"3dlut.input.profile": "",
+	"3dlut.abstract.profile": "",
 	"3dlut.output.profile": "",
 	"3dlut.output.profile.apply_cal": 1,
 	"3dlut.rendering_intent": 1,
+	"3dlut.use_abstract_profile": 0,
 	"3dlut.size": 0,
 	"allow_skip_sensor_cal": 0,
 	"argyll.debug": 0,
@@ -452,7 +485,7 @@ defaults = {
 	"lut_viewer.show": 0,
 	"lut_viewer.show_actual_lut": 0,
 	"measurement_mode": "l",
-	"measurement_mode.adaptive": 0,
+	"measurement_mode.adaptive": 1,
 	"measurement_mode.backup": "l",
 	"measurement_mode.highres": 0,
 	"measurement_mode.projector": 0,
@@ -467,6 +500,8 @@ defaults = {
 	"position.info.y": 50,
 	"position.lut_viewer.x": 50,
 	"position.lut_viewer.y": 50,
+	"position.lut3dframe.x": 50,
+	"position.lut3dframe.y": 50,
 	"position.profile_info.x": 50,
 	"position.profile_info.y": 50,
 	"position.progress.x": 50,
@@ -505,6 +540,8 @@ defaults = {
 	"show_advanced_calibration_options": 0,
 	"size.info.w": 512,
 	"size.info.h": 384,
+	"size.lut3dframe.w": 512,
+	"size.lut3dframe.h": 384,
 	"size.profile_info.w": 432,
 	"size.profile_info.split.w": 960,
 	"size.profile_info.h": 524,
@@ -535,7 +572,7 @@ defaults = {
 	"trc.type": "g",
 	"update_check": 1,
 	"use_separate_lut_access": 0,
-	"whitepoint.colortemp": 5000.0,
+	"whitepoint.colortemp": 5000,
 	"whitepoint.colortemp.locus": "t",
 	"whitepoint.x": 0.345741,
 	"whitepoint.y": 0.358666
@@ -687,6 +724,32 @@ def get_ccxx_testchart():
 									  defaults["colorimeter_correction.testchart"]))
 
 
+def get_current_profile(include_display_profile=False):
+	""" Get the currently selected profile (if any) """
+	path = getcfg("calibration.file")
+	if path:
+		import ICCProfile as ICCP
+		try:
+			profile = ICCP.ICCProfile(path)
+		except ICCP.ICCProfileInvalidError, exception:
+			return
+		return profile
+	elif include_display_profile:
+		return get_display_profile()
+
+
+def get_display_profile(display_no=None):
+	if display_no is None:
+		display_no = max(getcfg("display.number") - 1, 0)
+	import ICCProfile as ICCP
+	try:
+		return ICCP.get_display_profile(display_no)
+	except Exception, exception:
+		from log import _safe_print, log
+		_safe_print("ICCP.get_display_profile(%s):" % display_no, 
+					exception, fn=log)
+
+
 def get_total_patches(white_patches=None, single_channel_patches=None, 
 					  gray_patches=None, multi_steps=None, 
 					  fullspread_patches=None):
@@ -754,9 +817,26 @@ def get_verified_path(cfg_item_name, path=None):
 	return defaultDir, defaultFile
 
 
-def is_ccxx_testchart():
-	""" Check wether the current testchart is the default chart for CCMX/CCSS creation """
-	return getcfg("testchart.file") == get_ccxx_testchart()
+def is_ccxx_testchart(testchart=None):
+	""" Check wether the testchart is the default chart for CCMX/CCSS creation """
+	testchart = testchart or getcfg("testchart.file")
+	return testchart == get_ccxx_testchart()
+
+
+def is_profile(filename=None, include_display_profile=False):
+	filename = filename or getcfg("calibration.file")
+	if filename:
+		if os.path.exists(filename):
+			import ICCProfile as ICCP
+			try:
+				profile = ICCP.ICCProfile(filename)
+			except ICCP.ICCProfileInvalidError:
+				pass
+			else:
+				return True
+	elif include_display_profile:
+		return bool(get_display_profile())
+	return False
 
 
 def makecfgdir(which="user", worker=None):
