@@ -325,7 +325,13 @@ def setup():
 					(os.path.join(data, "lib"), 
 					 [sys.executable, sys.executable.replace(".exe", "w.exe")]),
 					(os.path.join(data, "scripts"), 
-					 [os.path.join("scripts", name + "-apply-profiles")])]
+					 [os.path.join("scripts", name + "-3DLUT-maker")]),
+					(os.path.join(data, "scripts"), 
+					 [os.path.join("scripts", name + "-apply-profiles")]),
+					(os.path.join(data, "scripts"), 
+					 [os.path.join("scripts", name + "-profile-info")]),
+					(os.path.join(data, "scripts"), 
+					 [os.path.join("scripts", name + "-testchart-editor")])]
 			else:
 				data_files += [(os.path.join(data, "theme", "icons"), 
 					glob.glob(os.path.join(pydir, "theme", 
@@ -507,12 +513,12 @@ setup(ext_modules = [Extension("%s.RealDisplaySizeMM", sources=%r,
 		"author": author_ascii,
 		"author_email": "%s@hoech.net" % name,
 		"classifiers": [
-			"Development Status :: 4 - Beta",
+			"Development Status :: 5 - Production/Stable",
 			"Environment :: MacOS X",
 			"Environment :: Win32 (MS Windows)",
 			"Environment :: X11 Applications",
 			"Intended Audience :: End Users/Desktop",
-			"License :: OSI Approved :: GNU General Public License (GPL)",
+			"License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
 			"Operating System :: OS Independent",
 			"Programming Language :: Python :: 2.5",
 			"Programming Language :: Python :: 2.6",
@@ -563,6 +569,9 @@ setup(ext_modules = [Extension("%s.RealDisplaySizeMM", sources=%r,
 		attrs["zip_safe"] = False
 	else:
 		attrs["scripts"] += [os.path.join("scripts", name)]
+		attrs["scripts"] += [os.path.join("scripts", name + "-3DLUT-maker")]
+		attrs["scripts"] += [os.path.join("scripts", name + "-profile-info")]
+		attrs["scripts"] += [os.path.join("scripts", name + "-testchart-editor")]
 	
 	if sys.platform != "darwin" and (sys.platform != "win32" or not do_py2exe):
 		attrs["scripts"] += [os.path.join("scripts", name + "-apply-profiles")]
